@@ -2,14 +2,14 @@ use std::io;
 use rand::Rng;
 use std::cmp::Ordering;
 
-
 fn main() {
+    println!("Welcome to Crispr guessing game!");
     println!("Guess the number!");
 
     let secret_number = rand::thread_rng().gen_range(1..=10);
 
     loop {
-        println!("please input your guess:");
+        println!("please input your guess or quit with 'quit':");
 
 
         //println!("The secret number is: {}", secret_number);
@@ -18,7 +18,6 @@ fn main() {
 
         io::stdin().read_line(&mut guess).expect("Error: failed to read line");
 
-
         let guess : u32 = match  guess.trim().parse() {
             Ok(num) => num,
             Err(_) => {
@@ -32,8 +31,14 @@ fn main() {
 
 
         match guess.cmp(&secret_number) {
-            Ordering::Less => println!("Too small :c"),
-            Ordering::Greater => println!("Too big :c"),
+            Ordering::Less => {
+                println!("Too small :c");
+            },
+
+            Ordering::Greater => {
+                println!("Too big :c");
+            },
+
             Ordering::Equal => {
                 println!("You Win :D");
                 break;
